SyncInstruction

Enum SyncInstruction 

pub enum SyncInstruction {
    V0(SyncRecordV0),
}
Versioned sync program instruction

Variants

Implementations

Source

impl SyncInstruction

pub fn pda(&self) -> Pubkey

Compute the record PDA for given ER node identity

pub fn identity(&self) -> &Pubkey

Returns identity pubkey of the ER node

pub fn addr(&mut self) -> &mut Option<String>

Returns address of the ER node, if set

pub fn base_fee(&mut self) -> &mut Option<u16>

Returns base transaction fee charged by ER node, if set

pub fn block_time_ms(&mut self) -> &mut Option<u16>

Returns the block time in ms of the given ER node, if set

pub fn features(&mut self) -> &mut Option<FeaturesSet>

Returns the features set supported by ER node, if set

pub fn status(&mut self) -> &mut Option<ErStatus>

Returns the status of ER node, if set

pub fn load_average(&mut self) -> &mut Option<u32>

Returns last observed average load on the given ER node, if set

pub fn country_code(&mut self) -> &mut Option<CountryCode>