pub struct SyncRecordV0 {
pub identity: Pubkey,
pub status: Option<ErStatus>,
pub block_time_ms: Option<u16>,
pub base_fee: Option<u16>,
pub features: Option<FeaturesSet>,
pub load_average: Option<u32>,
pub country_code: Option<CountryCode>,
pub addr: Option<String>,
}Expand description
Sync instruction data, version 0
Fields
identity: Pubkeystatus: Option<ErStatus>block_time_ms: Option<u16>base_fee: Option<u16>features: Option<FeaturesSet>load_average: Option<u32>country_code: Option<CountryCode>addr: Option<String>Trait Implementations
Sourceimpl BorshDeserialize for SyncRecordV0
impl BorshDeserialize for SyncRecordV0
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,