pub enum ErRecord {
V0(RecordV0),
}Variants
Implementations
Sourceimpl ErRecord
impl ErRecord
Sourcepub fn features(&self) -> &FeaturesSet
pub fn features(&self) -> &FeaturesSet
Returns supported set of features by the given ER node
Sourcepub fn block_time_ms(&self) -> u16
pub fn block_time_ms(&self) -> u16
Returns the block time in ms of the given ER node
Sourcepub fn load_average(&self) -> u32
pub fn load_average(&self) -> u32
Returns load average of the given ER node
Sourcepub fn country_code(&self) -> CountryCode
pub fn country_code(&self) -> CountryCode
Returns 3 digit country code of the given ER node
Sourcepub fn set_base_fee(&mut self, base_fee: u16)
pub fn set_base_fee(&mut self, base_fee: u16)
Updates base transaction fee in the given ER record
Sourcepub fn set_features(&mut self, features: FeaturesSet)
pub fn set_features(&mut self, features: FeaturesSet)
Updates the features set in the given ER record
Sourcepub fn set_block_time_ms(&mut self, block_time_ms: u16)
pub fn set_block_time_ms(&mut self, block_time_ms: u16)
Updates block time in ms in the given ER record
Sourcepub fn set_status(&mut self, status: ErStatus)
pub fn set_status(&mut self, status: ErStatus)
Updates node status for the given ER record
Sourcepub fn set_load_average(&mut self, load_average: u32)
pub fn set_load_average(&mut self, load_average: u32)
Updates the load average for the given ER record
Sourcepub fn set_country_code(&mut self, country_code: CountryCode)
pub fn set_country_code(&mut self, country_code: CountryCode)
Updates the country code for the given ER record