RecordV0

Struct RecordV0 

pub struct RecordV0 {
    pub identity: Pubkey,
    pub status: ErStatus,
    pub block_time_ms: u16,
    pub base_fee: u16,
    pub features: FeaturesSet,
    pub load_average: u32,
    pub country_code: CountryCode,
    pub addr: String,
}
Version 0 of ER domain registry record

Fields

identity: Pubkey

Identity of ER node (pubkey from its keypair)

status: ErStatus

Current status of ER node

block_time_ms: u16

Block time of given ER node in ms

base_fee: u16

Base fee charged by ER node per transaction

features: FeaturesSet

A bitmap of all possible combination of custom features that the ER node supports

load_average: u32

An average value, which is acts as an indicator of how loaded the given ER node currently is

country_code: CountryCode

3 digit country code, where ER node is deployed IBM spec was used as standard: https://www.ibm.com/docs/en/sia?topic=r-country-region-codes

addr: String

Variable length string representing FQDN