pub enum SyncInstruction {
V0(SyncRecordV0),
}Expand description
Versioned sync program instruction
Variants
V0(SyncRecordV0)
Implementations
Sourceimpl SyncInstruction
impl SyncInstruction
Sourcepub fn base_fee(&mut self) -> &mut Option<u16>
pub fn base_fee(&mut self) -> &mut Option<u16>
Returns base transaction fee charged by ER node, if set
Sourcepub fn block_time_ms(&mut self) -> &mut Option<u16>
pub fn block_time_ms(&mut self) -> &mut Option<u16>
Returns the block time in ms of the given ER node, if set
Sourcepub fn features(&mut self) -> &mut Option<FeaturesSet>
pub fn features(&mut self) -> &mut Option<FeaturesSet>
Returns the features set supported by ER node, if set
Sourcepub fn load_average(&mut self) -> &mut Option<u32>
pub fn load_average(&mut self) -> &mut Option<u32>
Returns last observed average load on the given ER node, if set
pub fn country_code(&mut self) -> &mut Option<CountryCode>