ErRecord

Enum ErRecord 

pub enum ErRecord {
    V0(RecordV0),
}

Variants

Implementations

Source

impl ErRecord

pub fn pda(&self) -> (Pubkey, u8)

Computes record’s PDA for the given ER node

pub fn seeds(&self) -> [&[u8]; 2]

Returns an array of seeds for the record’s PDA derivation

pub fn identity(&self) -> &Pubkey

Returns identity pubkey of the given ER

pub fn addr(&self) -> &str

Returns FQDN address for the given ER node

pub fn base_fee(&self) -> u16

Returns transaction fees of given ER node

pub fn features(&self) -> &FeaturesSet

Returns supported set of features by the given ER node

pub fn block_time_ms(&self) -> u16

Returns the block time in ms of the given ER node

pub fn status(&self) -> ErStatus

Returns current status of the given ER node

pub fn load_average(&self) -> u32

Returns load average of the given ER node

pub fn country_code(&self) -> CountryCode

Returns 3 digit country code of the given ER node

pub fn set_addr(&mut self, addr: String)

Updates the FQDN address in the given ER record

pub fn set_base_fee(&mut self, base_fee: u16)

Updates base transaction fee in the given ER record

pub fn set_features(&mut self, features: FeaturesSet)

Updates the features set in the given ER record

pub fn set_block_time_ms(&mut self, block_time_ms: u16)

Updates block time in ms in the given ER record

pub fn set_status(&mut self, status: ErStatus)

Updates node status for the given ER record

pub fn set_load_average(&mut self, load_average: u32)

Updates the load average for the given ER record

pub fn set_country_code(&mut self, country_code: CountryCode)

Updates the country code for the given ER record